@@ -1,9 +1,10 @@
 requireAll <- function(packages) {
 	.packages <- setdiff(packages, installed.packages()[,'Package'])
 	if(length(.packages)>0) {
+		suppressWarnings(rm(biocLite))
 		source("http://bioconductor.org/biocLite.R")
 		biocLite(.packages, dependencies=TRUE)
 	}
 	for(package in packages)
-		do.call(require, list(package))
+		suppressPackageStartupMessages(do.call(require, list(package)))
 }
